.. :Repository: https://github.com/abinit/abiflows

.. image:: https://badge.fury.io/py/abiflows.svg
        :target: https://badge.fury.io/py/abiflows

.. image:: https://travis-ci.org/abinit/abiflows.svg?branch=develop
        :target: https://travis-ci.org/abinit/abiflows

.. image:: https://coveralls.io/repos/github/abinit/abiflows/badge.svg?branch=develop
        :target: https://coveralls.io/github/abinit/abiflows?branch=develop

.. image:: https://img.shields.io/badge/license-GPL-blue.svg

.. image:: https://img.shields.io/badge/docs-ff69b4.svg
     :alt: Abiflows Documentation
     :target: http://abinit.github.io/abiflows/


About
=====

Abiflows provides fireworks workflows to run several kind of DFT/DFPT simulations with Abinit. 
